@@ -16,6 +16,9 @@ pub use escape_c_keyword::EscapeCKeyword;
 mod escape_cpp_keyword;
 pub use escape_cpp_keyword::EscapeCppKeyword;
 
+mod escape_js_keyword;
+pub use escape_js_keyword::EscapeJsKeyword;
+
 pub fn invalid_input<S>(cause: S) -> liquid_core::Error
 where
     S: Into<liquid_core::model::KString>,
@@ -31,5 +34,6 @@ pub(crate) fn all() -> Vec<Box<dyn liquid_core::parser::ParseFilter>> {
         crate::filters::EscapeRustKeyword.into(),
         crate::filters::EscapeCKeyword.into(),
         crate::filters::EscapeCppKeyword.into(),
+        crate::filters::EscapeJsKeyword.into(),
     ]
 }
